using System;
using CMS.SettingsProvider;

/// <summary>
/// Summary description for SiteRegistration
/// </summary>
public class SiteRegistration : IDataContainer
{
    #region "Variables"

    private string mSiteOwner = null;
    private DateTime mSiteValidUntil = DateTime.MinValue;

    #endregion


    #region "Properties"

    /// <summary>
    /// Gets or sets the site owner
    /// </summary>
    public string SiteOwner
    {
        get
        {
            return mSiteOwner;
        }
        set
        {
            mSiteOwner = value;
        }
    }


    /// <summary>
    /// Gets or sets the date until which the site is valid
    /// </summary>
    public DateTime SiteValidUntil
    {
        get
        {
            return mSiteValidUntil;
        }
        set
        {
            mSiteValidUntil = value;
        }
    }
    
    #endregion


    #region "IDataContainer members"

    /// <summary>
    /// Gets the column names
    /// </summary>
    public string[] ColumnNames
    {
        get 
        { 
            return new string[] { "SiteOwner", "SiteValidUntil" };
        }
    }


    /// <summary>
    /// Returns true
    /// </summary>
    /// <param name="columnName"></param>
    public bool ContainsColumn(string columnName)
    {
        switch (columnName.ToLower())
        {
            case "siteowner":
            case "sitevaliduntil":
                return true;

            default:
                return false;
        }
    }


    /// <summary>
    /// Gets the object value
    /// </summary>
    /// <param name="columnName">Column name</param>
    public object GetValue(string columnName)
    {
        switch (columnName.ToLower())
        {
            case "siteowner":
                return mSiteOwner;

            case "sitevaliduntil":
                return mSiteValidUntil;

            default:
                return null;
        }
    }


    /// <summary>
    /// Sets the field value
    /// </summary>
    /// <param name="columnName">Column name</param>
    /// <param name="value">New value</param>
    public bool SetValue(string columnName, object value)
    {
        switch (columnName.ToLower())
        {
            case "siteowner":
                mSiteOwner = (string)value;
                return true;

            case "sitevaliduntil":
                mSiteValidUntil = (DateTime)value;
                return true;

            default:
                return false;
        }
    }


    /// <summary>
    /// Tries to get the value from the object
    /// </summary>
    /// <param name="columnName">Column name</param>
    /// <param name="value">Returns the value</param>
    public bool TryGetValue(string columnName, out object value)
    {
        switch (columnName.ToLower())
        {
            case "siteowner":
                value = mSiteOwner;
                return true;

            case "sitevaliduntil":
                value = mSiteValidUntil;
                return true;

            default:
                value = null;
                return false;
        }
    }

    #endregion


    #region "Methods"

    /// <summary>
    /// Returns true if the site is valid
    /// </summary>
    public bool IsValid()
    {
        return this.SiteValidUntil > DateTime.Now;
    }

    #endregion
}
